# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKVideoCorePython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkVideoStreamPython
else:
    import _itkVideoStreamPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkRingBufferPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkTemporalDataObjectPython
import itk.itkTemporalRegionPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython

def itkVideoStreamIF2_New():
    return itkVideoStreamIF2.New()

class itkVideoStreamIF2(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamIF2_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamIF2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamIF2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamIF2_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamIF2_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamIF2_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF2_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF2_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF2_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF2_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF2_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF2_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkImageF2_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkImageF2

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkImageF2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD22

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamIF2_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamIF2

        Create a new object of the class itkVideoStreamIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamIF2 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamIF2_swigregister(itkVideoStreamIF2)

def itkVideoStreamIF3_New():
    return itkVideoStreamIF3.New()

class itkVideoStreamIF3(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamIF3_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamIF3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamIF3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamIF3_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamIF3_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamIF3_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF3_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF3_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF3_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF3_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF3_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIF3_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkImageF3_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkImageF3

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkImageF3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD33

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamIF3_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamIF3

        Create a new object of the class itkVideoStreamIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamIF3 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamIF3_swigregister(itkVideoStreamIF3)

def itkVideoStreamISS2_New():
    return itkVideoStreamISS2.New()

class itkVideoStreamISS2(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamISS2_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamISS2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamISS2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamISS2_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamISS2_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamISS2_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS2_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS2_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS2_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS2_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS2_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS2_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkImageSS2_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkImageSS2

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkImageSS2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD22

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamISS2_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamISS2

        Create a new object of the class itkVideoStreamISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamISS2 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamISS2_swigregister(itkVideoStreamISS2)

def itkVideoStreamISS3_New():
    return itkVideoStreamISS3.New()

class itkVideoStreamISS3(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamISS3_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamISS3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamISS3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamISS3_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamISS3_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamISS3_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS3_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS3_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS3_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS3_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS3_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamISS3_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkImageSS3_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkImageSS3

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkImageSS3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD33

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamISS3_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamISS3

        Create a new object of the class itkVideoStreamISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamISS3 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamISS3_swigregister(itkVideoStreamISS3)

def itkVideoStreamIUC2_New():
    return itkVideoStreamIUC2.New()

class itkVideoStreamIUC2(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamIUC2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamIUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamIUC2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamIUC2_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamIUC2_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkImageUC2_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkImageUC2

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkImageUC2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD22

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamIUC2_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamIUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamIUC2

        Create a new object of the class itkVideoStreamIUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamIUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamIUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamIUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamIUC2 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamIUC2_swigregister(itkVideoStreamIUC2)

def itkVideoStreamIUC3_New():
    return itkVideoStreamIUC3.New()

class itkVideoStreamIUC3(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamIUC3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamIUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamIUC3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamIUC3_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamIUC3_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkImageUC3_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkImageUC3

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkImageUC3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD33

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamIUC3_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamIUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamIUC3

        Create a new object of the class itkVideoStreamIUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamIUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamIUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamIUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamIUC3 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamIUC3_swigregister(itkVideoStreamIUC3)

def itkVideoStreamVIF2_New():
    return itkVideoStreamVIF2.New()

class itkVideoStreamVIF2(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamVIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamVIF2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamVIF2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVIF2_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamVIF2_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkVectorImageF2_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkVectorImageF2

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkVectorImageF2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD22

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamVIF2_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamVIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamVIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamVIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamVIF2

        Create a new object of the class itkVideoStreamVIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamVIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamVIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamVIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamVIF2 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamVIF2_swigregister(itkVideoStreamVIF2)

def itkVideoStreamVIF3_New():
    return itkVideoStreamVIF3.New()

class itkVideoStreamVIF3(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamVIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamVIF3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamVIF3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVIF3_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamVIF3_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkVectorImageF3_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkVectorImageF3

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkVectorImageF3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD33

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamVIF3_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamVIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamVIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamVIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamVIF3

        Create a new object of the class itkVideoStreamVIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamVIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamVIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamVIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamVIF3 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamVIF3_swigregister(itkVideoStreamVIF3)

def itkVideoStreamVISS2_New():
    return itkVideoStreamVISS2.New()

class itkVideoStreamVISS2(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamVISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamVISS2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamVISS2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVISS2_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamVISS2_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkVectorImageSS2_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkVectorImageSS2

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkVectorImageSS2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD22

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamVISS2_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamVISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamVISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamVISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamVISS2

        Create a new object of the class itkVideoStreamVISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamVISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamVISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamVISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamVISS2 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamVISS2_swigregister(itkVideoStreamVISS2)

def itkVideoStreamVISS3_New():
    return itkVideoStreamVISS3.New()

class itkVideoStreamVISS3(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamVISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamVISS3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamVISS3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVISS3_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamVISS3_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkVectorImageSS3_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkVectorImageSS3

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkVectorImageSS3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD33

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamVISS3_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamVISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamVISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamVISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamVISS3

        Create a new object of the class itkVideoStreamVISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamVISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamVISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamVISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamVISS3 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamVISS3_swigregister(itkVideoStreamVISS3)

def itkVideoStreamVIUC2_New():
    return itkVideoStreamVIUC2.New()

class itkVideoStreamVIUC2(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamVIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamVIUC2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVIUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamVIUC2_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVIUC2_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamVIUC2_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD2,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD2 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD22,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD22 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkVectorImageUC2_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkVectorImageUC2

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkVectorImageUC2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD2

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD22

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion2

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD2

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD2

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD22

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamVIUC2_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamVIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamVIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamVIUC2

        Create a new object of the class itkVideoStreamVIUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamVIUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamVIUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamVIUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamVIUC2 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamVIUC2_swigregister(itkVideoStreamVIUC2)

def itkVideoStreamVIUC3_New():
    return itkVideoStreamVIUC3.New()

class itkVideoStreamVIUC3(itk.itkTemporalDataObjectPython.itkTemporalDataObject):
    r"""Proxy of C++ itkVideoStreamVIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetFrameDimension():
        r"""GetFrameDimension() -> unsigned int"""
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetFrameDimension()

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVideoStreamVIUC3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVIUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVideoStreamVIUC3_Pointer"""
        return _itkVideoStreamPython.itkVideoStreamVIUC3_Clone(self)

    def SetMinimumBufferSize(self, minimumNumberOfFrames):
        r"""
        SetMinimumBufferSize(self, minimumNumberOfFrames)

        Parameters
        ----------
        minimumNumberOfFrames: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetMinimumBufferSize(self, minimumNumberOfFrames)

    def InitializeEmptyFrames(self):
        r"""InitializeEmptyFrames(self)"""
        return _itkVideoStreamPython.itkVideoStreamVIUC3_InitializeEmptyFrames(self)

    def GetFrameBuffer(self, *args):
        r"""
        GetFrameBuffer(self) -> itkRingBufferDO
        GetFrameBuffer(self) -> itkRingBufferDO
        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetFrameBuffer(self, *args)

    def SetFrameBuffer(self, buffer):
        r"""
        SetFrameBuffer(self, buffer)

        Parameters
        ----------
        buffer: itkRingBufferDO *

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetFrameBuffer(self, buffer)

    def GetLargestPossibleSpatialRegionCache(self):
        r"""GetLargestPossibleSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetLargestPossibleSpatialRegionCache(self)

    def SetLargestPossibleSpatialRegionCache(self, map):
        r"""
        SetLargestPossibleSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetLargestPossibleSpatialRegionCache(self, map)

    def GetRequestedSpatialRegionCache(self):
        r"""GetRequestedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetRequestedSpatialRegionCache(self)

    def SetRequestedSpatialRegionCache(self, map):
        r"""
        SetRequestedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetRequestedSpatialRegionCache(self, map)

    def GetBufferedSpatialRegionCache(self):
        r"""GetBufferedSpatialRegionCache(self) -> std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetBufferedSpatialRegionCache(self)

    def SetBufferedSpatialRegionCache(self, map):
        r"""
        SetBufferedSpatialRegionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkImageRegion3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkImageRegion3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetBufferedSpatialRegionCache(self, map)

    def GetSpacingCache(self):
        r"""GetSpacingCache(self) -> std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetSpacingCache(self)

    def SetSpacingCache(self, map):
        r"""
        SetSpacingCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkVectorD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkVectorD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetSpacingCache(self, map)

    def GetOriginCache(self):
        r"""GetOriginCache(self) -> std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetOriginCache(self)

    def SetOriginCache(self, map):
        r"""
        SetOriginCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkPointD3,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkPointD3 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetOriginCache(self, map)

    def GetDirectionCache(self):
        r"""GetDirectionCache(self) -> std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > > const &"""
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetDirectionCache(self)

    def SetDirectionCache(self, map):
        r"""
        SetDirectionCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,itkMatrixD33,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkMatrixD33 > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetDirectionCache(self, map)

    def GetNumberOfComponentsPerPixelCache(self, *args):
        r"""
        GetNumberOfComponentsPerPixelCache(self) -> std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > > const
        GetNumberOfComponentsPerPixelCache(self, map)

        Parameters
        ----------
        map: std::map< unsigned long,unsigned int,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,unsigned int > > >

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetNumberOfComponentsPerPixelCache(self, *args)

    def SetFrame(self, frameNumber, frame):
        r"""
        SetFrame(self, frameNumber, frame)

        Parameters
        ----------
        frameNumber: unsigned long
        frame: itkVectorImageUC3_Pointer

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetFrame(self, frameNumber, frame)

    def GetFrame(self, *args):
        r"""
        GetFrame(self, frameNumber) -> itkVectorImageUC3

        Parameters
        ----------
        frameNumber: unsigned long

        GetFrame(self, frameNumber) -> itkVectorImageUC3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetFrame(self, *args)

    def SetFrameLargestPossibleSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetFrameLargestPossibleSpatialRegion(self, frameNumber, region)

    def GetFrameLargestPossibleSpatialRegion(self, frameNumber):
        r"""
        GetFrameLargestPossibleSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetFrameLargestPossibleSpatialRegion(self, frameNumber)

    def SetFrameRequestedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameRequestedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetFrameRequestedSpatialRegion(self, frameNumber, region)

    def GetFrameRequestedSpatialRegion(self, frameNumber):
        r"""
        GetFrameRequestedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetFrameRequestedSpatialRegion(self, frameNumber)

    def SetFrameBufferedSpatialRegion(self, frameNumber, region):
        r"""
        SetFrameBufferedSpatialRegion(self, frameNumber, region)

        Parameters
        ----------
        frameNumber: unsigned long
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetFrameBufferedSpatialRegion(self, frameNumber, region)

    def GetFrameBufferedSpatialRegion(self, frameNumber):
        r"""
        GetFrameBufferedSpatialRegion(self, frameNumber) -> itkImageRegion3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetFrameBufferedSpatialRegion(self, frameNumber)

    def SetFrameSpacing(self, frameNumber, spacing):
        r"""
        SetFrameSpacing(self, frameNumber, spacing)

        Parameters
        ----------
        frameNumber: unsigned long
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetFrameSpacing(self, frameNumber, spacing)

    def GetFrameSpacing(self, frameNumber):
        r"""
        GetFrameSpacing(self, frameNumber) -> itkVectorD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetFrameSpacing(self, frameNumber)

    def SetFrameOrigin(self, frameNumber, origin):
        r"""
        SetFrameOrigin(self, frameNumber, origin)

        Parameters
        ----------
        frameNumber: unsigned long
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetFrameOrigin(self, frameNumber, origin)

    def GetFrameOrigin(self, frameNumber):
        r"""
        GetFrameOrigin(self, frameNumber) -> itkPointD3

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetFrameOrigin(self, frameNumber)

    def SetFrameDirection(self, frameNumber, direction):
        r"""
        SetFrameDirection(self, frameNumber, direction)

        Parameters
        ----------
        frameNumber: unsigned long
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetFrameDirection(self, frameNumber, direction)

    def GetFrameDirection(self, frameNumber):
        r"""
        GetFrameDirection(self, frameNumber) -> itkMatrixD33

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetFrameDirection(self, frameNumber)

    def SetFrameNumberOfComponentsPerPixel(self, frameNumber, n):
        r"""
        SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

        Parameters
        ----------
        frameNumber: unsigned long
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetFrameNumberOfComponentsPerPixel(self, frameNumber, n)

    def GetFrameNumberOfComponentsPerPixel(self, frameNumber):
        r"""
        GetFrameNumberOfComponentsPerPixel(self, frameNumber) -> unsigned int const &

        Parameters
        ----------
        frameNumber: unsigned long

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_GetFrameNumberOfComponentsPerPixel(self, frameNumber)

    def SetAllLargestPossibleSpatialRegions(self, region):
        r"""
        SetAllLargestPossibleSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetAllLargestPossibleSpatialRegions(self, region)

    def SetAllRequestedSpatialRegions(self, region):
        r"""
        SetAllRequestedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetAllRequestedSpatialRegions(self, region)

    def SetAllBufferedSpatialRegions(self, region):
        r"""
        SetAllBufferedSpatialRegions(self, region)

        Parameters
        ----------
        region: itkImageRegion3

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetAllBufferedSpatialRegions(self, region)

    def SetAllFramesSpacing(self, spacing):
        r"""
        SetAllFramesSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD3

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetAllFramesSpacing(self, spacing)

    def SetAllFramesOrigin(self, origin):
        r"""
        SetAllFramesOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD3

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetAllFramesOrigin(self, origin)

    def SetAllFramesDirection(self, direction):
        r"""
        SetAllFramesDirection(self, direction)

        Parameters
        ----------
        direction: itkMatrixD33

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetAllFramesDirection(self, direction)

    def SetAllFramesNumberOfComponentsPerPixel(self, n):
        r"""
        SetAllFramesNumberOfComponentsPerPixel(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_SetAllFramesNumberOfComponentsPerPixel(self, n)

    def Allocate(self):
        r"""Allocate(self)"""
        return _itkVideoStreamPython.itkVideoStreamVIUC3_Allocate(self)
    __swig_destroy__ = _itkVideoStreamPython.delete_itkVideoStreamVIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVideoStreamVIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVideoStreamPython.itkVideoStreamVIUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVideoStreamVIUC3

        Create a new object of the class itkVideoStreamVIUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVideoStreamVIUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVideoStreamVIUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVideoStreamVIUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVideoStreamVIUC3 in _itkVideoStreamPython:
_itkVideoStreamPython.itkVideoStreamVIUC3_swigregister(itkVideoStreamVIUC3)

